Function parse_internal_attribute
pub fn parse_internal_attribute<'a>(
model_name: &str,
raw: &'a str,
) -> Result<&'a str, String>Expand description
Parses one @@internal("action") attribute’s action name and
validates it against INTERNAL_ACTIONS. Returns Err naming the
model and the bad action for anything else — the compile-error case
the design’s acceptance criteria requires (“@@internal naming an
action that is not a valid action verb ⇒ compile error naming the
model and the bad action”).